@@ -1,4 +1,10 @@
 use v5.26;
+
+use strict;
+use warnings;
+no indirect;
+use feature 'signatures';
+
 use Object::Pad ':experimental(init_expr)';
 # ABSTRACT: ABI utility for encoding ethereum contract arguments
 
@@ -6,7 +12,7 @@ package Blockchain::Ethereum::ABI::Encoder;
 class Blockchain::Ethereum::ABI::Encoder;
 
 our $AUTHORITY = 'cpan:REFECO';    # AUTHORITY
-our $VERSION   = '0.013';          # VERSION
+our $VERSION   = '0.014';          # VERSION
 
 use Carp;
 use Crypt::Digest::Keccak256 qw(keccak256_hex);
@@ -82,7 +88,7 @@ Blockchain::Ethereum::ABI::Encoder - ABI utility for encoding ethereum contract
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
